bayespy.inference.vmp.transformations.RotateGaussianMarkovChain.rotate
======================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussianMarkovChain.rotate